==> create-gooddata-react-app-0.1.30-0.tgz: src/routes/StaticDashboard.js <==
import React, { useState } from "react";
import cx from "classnames";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";

import C from "../constants";
import Page from "../components/Page";
import YearSelect from "../components/YearSelect";
import VisTypePicker from "../components/VisTypePicker";

import ByStateColumnChart from "../components/StaticDashboard/ByStateColumnChart";
import ByStateLineChart from "../components/StaticDashboard/ByStateLineChart";
import ByStateMap from "../components/StaticDashboard/ByStateMap";
import ByStateStackedAreaChart from "../components/StaticDashboard/ByStateStackedAreaChart";
import ByStateTreemap from "../components/StaticDashboard/ByStateTreemap";
import EmployeeKPI from "../components/StaticDashboard/EmployeeKPI";
import EmployeeTable from "../components/StaticDashboard/EmployeeTable";
import MainKPI from "../components/StaticDashboard/MainKPI";
import MenuCategoryDonut from "../components/StaticDashboard/MenuCategoryDonut";
import PercentKpi from "../components/StaticDashboard/PercentKPI";
import PeriodComparisonKPI from "../components/StaticDashboard/PeriodComparisonKPI";
import visStyles from "../components/StaticDashboard/Visualizations.module.scss";

import sharedStyles from "../shared.module.scss";
import styles from "./Home.module.scss";
import userUri from "../media/user.svg";

const byStateVisTypes = ["columnChart", "lineChart", "areaChart", "treemap"];

const byStateComponentMap = {
    columnChart: ByStateColumnChart,
    lineChart: ByStateLineChart,
    areaChart: ByStateStackedAreaChart,
    treemap: ByStateTreemap,
};

const StaticDashboard = () => {
    const [selectedYear, setSelectedYear] = useState(2017);
    const [byStateVisType, setByStateVisType] = useState(byStateVisTypes[0]);
    const [selectedEmployee, setSelectedEmployee] = useState(null);

    const dateFilters = [
        Model.absoluteDateFilter(C.dateDataset, `${selectedYear}-01-01`, `${selectedYear}-12-31`),
    ];

    const employeeFilters = selectedEmployee
        ? [Model.attributeFilter(C.attributeDisplayForms.employeeName).inUris(selectedEmployee.header.uri)]
        : [];

    const effectiveFilters = [...employeeFilters, ...dateFilters];

    const ByStateVis = byStateComponentMap[byStateVisType];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Overview Dashboard</h2>
                            <YearSelect value={selectedYear} onChange={setSelectedYear} />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col lg={4}>
                        <MainKPI filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <PercentKpi filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <PeriodComparisonKPI filters={dateFilters} />
                    </Col>
                </Row>
                <Row>
                    <Col lg={8}>
                        <h3 className={cx(visStyles.Heading, styles.HeadingWithAside)}>
                            <span>Profit By State&emsp;</span>
                            <VisTypePicker
                                className={styles.VisPickerInline}
                                value={byStateVisType}
                                visTypes={byStateVisTypes}
                                onChange={setByStateVisType}
                            />
                        </h3>

                        <ByStateVis filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <ByStateMap filters={dateFilters} />
                    </Col>
                </Row>
                <Row>
                    <Col lg={8}>
                        <EmployeeTable filters={dateFilters} onDrill={setSelectedEmployee} />
                    </Col>
                    <Col lg={4}>
                        <h3 className={cx(visStyles.Heading, styles.Ellipsis)}>
                            <span className={styles.CircleIcon}>
                                <img src={userUri} alt="" />
                            </span>
                            &ensp;{selectedEmployee ? selectedEmployee.title : "All Employees"}
                        </h3>
                        {selectedEmployee && (
                            <div className={styles.Clear}>
                                <button
                                    className={sharedStyles.Link}
                                    onClick={() => setSelectedEmployee(null)}
                                >
                                    clear
                                </button>
                            </div>
                        )}
                        <EmployeeKPI filters={effectiveFilters} />
                        <MenuCategoryDonut filters={effectiveFilters} />
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default StaticDashboard;

==> create-gooddata-react-app-0.1.31-0.tgz: src/routes/StaticDashboard.js <==
import React, { useState } from "react";
import cx from "classnames";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";

import C from "../constants";
import Page from "../components/Page";
import VisTypePicker from "../components/VisTypePicker";
import useYearFilter from "../hooks/useYearFilter";
import LoadableYearSelect from "../components/LoadableYearSelect";

import ByStateColumnChart from "../components/StaticDashboard/ByStateColumnChart";
import ByStateLineChart from "../components/StaticDashboard/ByStateLineChart";
import ByStateMap from "../components/StaticDashboard/ByStateMap";
import ByStateStackedAreaChart from "../components/StaticDashboard/ByStateStackedAreaChart";
import ByStateTreemap from "../components/StaticDashboard/ByStateTreemap";
import EmployeeKPI from "../components/StaticDashboard/EmployeeKPI";
import EmployeeTable from "../components/StaticDashboard/EmployeeTable";
import MainKPI from "../components/StaticDashboard/MainKPI";
import MenuCategoryDonut from "../components/StaticDashboard/MenuCategoryDonut";
import PercentKpi from "../components/StaticDashboard/PercentKPI";
import PeriodComparisonKPI from "../components/StaticDashboard/PeriodComparisonKPI";

import visStyles from "../components/StaticDashboard/Visualizations.module.scss";
import sharedStyles from "../shared.module.scss";
import styles from "./Home.module.scss";
import userUri from "../media/user.svg";

const byStateVisTypes = ["columnChart", "lineChart", "areaChart", "treemap"];

const byStateComponentMap = {
    columnChart: ByStateColumnChart,
    lineChart: ByStateLineChart,
    areaChart: ByStateStackedAreaChart,
    treemap: ByStateTreemap,
};

const StaticDashboard = () => {
    const [selectedYear, selectedYearFilter, setSelectedYear] = useYearFilter();
    const [byStateVisType, setByStateVisType] = useState(byStateVisTypes[0]);
    const [selectedEmployee, setSelectedEmployee] = useState(null);

    const dateFilters = [selectedYearFilter];

    const employeeFilters = selectedEmployee
        ? [Model.attributeFilter(C.attributeDisplayForms.employeeName).inUris(selectedEmployee.header.uri)]
        : [];

    const effectiveFilters = [...employeeFilters, ...dateFilters];

    const ByStateVis = byStateComponentMap[byStateVisType];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Overview Dashboard</h2>
                            <LoadableYearSelect
                                selectedYear={selectedYear}
                                setSelectedYear={setSelectedYear}
                            />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col lg={4}>
                        <MainKPI filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <PercentKpi filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <PeriodComparisonKPI filters={dateFilters} />
                    </Col>
                </Row>
                <Row>
                    <Col lg={8}>
                        <h3 className={cx(visStyles.Heading, styles.HeadingWithAside)}>
                            <span>Profit By State&emsp;</span>
                            <VisTypePicker
                                className={styles.VisPickerInline}
                                value={byStateVisType}
                                visTypes={byStateVisTypes}
                                onChange={setByStateVisType}
                            />
                        </h3>

                        <ByStateVis filters={dateFilters} />
                    </Col>
                    <Col lg={4}>
                        <ByStateMap filters={dateFilters} />
                    </Col>
                </Row>
                <Row>
                    <Col lg={8}>
                        <EmployeeTable filters={dateFilters} onDrill={setSelectedEmployee} />
                    </Col>
                    <Col lg={4}>
                        <h3 className={cx(visStyles.Heading, styles.Ellipsis)}>
                            <span className={styles.CircleIcon}>
                                <img src={userUri} alt="" />
                            </span>
                            &ensp;{selectedEmployee ? selectedEmployee.title : "All Employees"}
                        </h3>
                        {selectedEmployee && (
                            <div className={styles.Clear}>
                                <button
                                    className={sharedStyles.Link}
                                    onClick={() => setSelectedEmployee(null)}
                                >
                                    clear
                                </button>
                            </div>
                        )}
                        <EmployeeKPI filters={effectiveFilters} />
                        <MenuCategoryDonut filters={effectiveFilters} />
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default StaticDashboard;
